@@ -6,7 +6,7 @@ from __future__ import with_statement
 
 from pipes import quote
 
-from fabric.api import *
+from fabric.api import hide, run, settings
 
 from fabtools.utils import run_as_root
 
