@@ -11,6 +11,8 @@ from __future__ import with_statement
 from fabric.utils import puts
 
 from fabtools.deb import (
+    add_apt_key,
+    apt_key_exists,
     install,
     is_installed,
     uninstall,
@@ -21,6 +23,32 @@ from fabtools.system import distrib_codename
 from fabtools.utils import run_as_root
 
 
+def key(keyid, filename=None, url=None, keyserver='subkeys.pgp.net', update=False):
+    """
+    Require a PGP key for APT.
+
+    ::
+
+        from fabtools import require
+
+        # Varnish signing key from URL
+        require.deb.key('C4DEFFEB', url='http://repo.varnish-cache.org/debian/GPG-key.txt')
+
+        # Nginx signing key from default key server (subkeys.pgp.net)
+        require.deb.key('7BD9BF62')
+
+        # From custom key server
+        require.deb.key('7BD9BF62', keyserver='keyserver.ubuntu.com')
+
+        # From file
+        require.deb.key('7BD9BF62', filename='nginx.asc')
+
+    """
+
+    if not apt_key_exists(keyid):
+        add_apt_key(keyid=keyid, filename=filename, url=url, keyserver=keyserver, update=update)
+
+
 def source(name, uri, distribution, *components):
     """
     Require a package source.
@@ -70,7 +98,7 @@ def ppa(name):
         update_index()
 
 
-def package(pkg_name, update=False):
+def package(pkg_name, update=False, version=None):
     """
     Require a deb package to be installed.
 
@@ -78,10 +106,15 @@ def package(pkg_name, update=False):
 
         from fabtools import require
 
+        # Require a package
         require.deb.package('foo')
+
+        # Require a specific version
+        require.deb.package('firefox', version='11.0+build1-0ubuntu4')
+
     """
     if not is_installed(pkg_name):
-        install(pkg_name, update)
+        install(pkg_name, update=update, version=version)
 
 
 def packages(pkg_list, update=False):
