@@ -1,6 +1,6 @@
 from __future__ import with_statement
 
-from fabric.api import *
+from fabric.api import task, settings
 
 
 @task
